Logo ResizeArray

ResizeArrayT Namespace

Type/Module Description

Array

This module has only one conversion function. Array.asResizeArray

AutoOpenComputationalExpression

This module is automatically opened when the namespace ResizeArrayT is opened. It provides a computational expression builder for ResizeArray<'T>. resizeArray { ... } This builder allows you to create a ResizeArray just like you would create an IEnumerable with seq expressions seq { ... }.

AutoOpenResizeArrayExtensions

Extension methods for ResizeArray<'T>. This module is automatically opened when the namespace ResizeArrayT is opened.

Operators

Open this module to get access to the operators +++ and ++ to combine the contents of two sequences or ICollection<'T> values into a new ResizeArray.

ResizeArray

The main module for functions on ResizeArray. A ResizeArray is a System.Collections.Generic.List<'T>. This module has all functions from the FSharp.Core.Array module implemented for ResizeArray. And more.

ResizeArrayParallel

This module only holds the ResizeArray.Parallel module. It is AutoOpen, so that ResizeArray.Parallel is available after 'open ResizeArrayT', next to the functions of the main ResizeArray module in Module.fs. (F# can't split one module over several files.)

ResizeArrayTArgumentException

Invalid argument to a ResizeArrayT operation.

ResizeArrayTArgumentNullException

A required ResizeArray or projected value was null.

ResizeArrayTKeyNotFoundException

No matching item was found.

Type something to start searching.