Logo ResizeArray

ComputationalExpressionBuilderResizeArray<'T> Type

Builds ResizeArray values using F# computation-expression syntax.

Constructors

Constructor Description

ComputationalExpressionBuilderResizeArray()

Full Usage: ComputationalExpressionBuilderResizeArray()

Returns: ComputationalExpressionBuilderResizeArray<'T>

Instance members

Instance member Description

this.Combine

Full Usage: this.Combine

Parameters:
    f : ResizeArray<'T> -> unit - The first body.
    g : ResizeArray<'T> -> 'a - The second body.

Returns: ResizeArray<'T> -> 'a
Modifiers: inline

Combines two consecutive computation-expression bodies.

f : ResizeArray<'T> -> unit

The first body.

g : ResizeArray<'T> -> 'a

The second body.

Returns: ResizeArray<'T> -> 'a

this.Delay

Full Usage: this.Delay

Parameters:
    f : unit -> ResizeArray<'T> -> 'a - The function that creates the delayed body.

Returns: ResizeArray<'T> -> 'a
Modifiers: inline

Delays creation of a computation-expression body until it is executed.

f : unit -> ResizeArray<'T> -> 'a

The function that creates the delayed body.

Returns: ResizeArray<'T> -> 'a

this.For

Full Usage: this.For

Parameters:
    xs : 'U seq - The sequence to iterate.
    body : 'U -> ResizeArray<'T> -> unit - The body to execute for each value.

Returns: ResizeArray<'T> -> unit
Modifiers: inline

Iterates a sequence and executes the body for each value. This always allocates a sequence and an enumerator, even for i = 0 to x. Use a while loop to avoid that allocation.

xs : 'U seq

The sequence to iterate.

body : 'U -> ResizeArray<'T> -> unit

The body to execute for each value.

Returns: ResizeArray<'T> -> unit

this.Run

Full Usage: this.Run

Parameters:
    body : ResizeArray<'T> -> unit - The body to execute.

Returns: ResizeArray<'T>
Modifiers: inline

Executes the computation-expression body and returns the resulting ResizeArray.

body : ResizeArray<'T> -> unit

The body to execute.

Returns: ResizeArray<'T>

this.TryFinally

Full Usage: this.TryFinally

Parameters:
    body : ResizeArray<'T> -> unit - The body to execute.
    compensation : ResizeArray<'T> -> unit - The compensation to execute afterwards.

Returns: ResizeArray<'T> -> unit
Modifiers: inline

Executes the compensation after the body completes or raises an exception.

body : ResizeArray<'T> -> unit

The body to execute.

compensation : ResizeArray<'T> -> unit

The compensation to execute afterwards.

Returns: ResizeArray<'T> -> unit

this.TryWith

Full Usage: this.TryWith

Parameters:
    body : ResizeArray<'T> -> unit - The body to execute.
    handler : exn -> ResizeArray<'T> -> unit - The exception handler.

Returns: ResizeArray<'T> -> unit
Modifiers: inline

Executes the body and invokes the handler if the body raises an exception.

body : ResizeArray<'T> -> unit

The body to execute.

handler : exn -> ResizeArray<'T> -> unit

The exception handler.

Returns: ResizeArray<'T> -> unit

this.Using

Full Usage: this.Using

Parameters:
    disposable : 'a - The resource to dispose.
    body : 'a -> ResizeArray<'T> -> unit - The body to execute with the resource.

Returns: ResizeArray<'T> -> unit
Modifiers: inline

Executes the body and disposes the supplied resource afterwards.

disposable : 'a

The resource to dispose.

body : 'a -> ResizeArray<'T> -> unit

The body to execute with the resource.

Returns: ResizeArray<'T> -> unit

this.While

Full Usage: this.While

Parameters:
    predicate : unit -> bool - The function that controls iteration.
    body : ResizeArray<'T> -> unit - The body to execute.

Returns: ResizeArray<'T> -> unit
Modifiers: inline

Repeatedly executes the body while the predicate returns true.

predicate : unit -> bool

The function that controls iteration.

body : ResizeArray<'T> -> unit

The body to execute.

Returns: ResizeArray<'T> -> unit

this.Yield

Full Usage: this.Yield

Parameters:
    x : 'T - The value to add.

Returns: ResizeArray<'T> -> unit
Modifiers: inline

Adds one value to the ResizeArray produced by the computation expression.

x : 'T

The value to add.

Returns: ResizeArray<'T> -> unit

this.YieldFrom

Full Usage: this.YieldFrom

Parameters:
    xs : 'a - The sequence of values to add.

Returns: ResizeArray<'T0> -> unit
Modifiers: inline

Adds all values from a sequence to the ResizeArray produced by the computation expression.

xs : 'a

The sequence of values to add.

Returns: ResizeArray<'T0> -> unit

this.Zero

Full Usage: this.Zero

Returns: 'a -> unit
Modifiers: inline

Called for empty else branches of if...then expressions in computation expressions.

Returns: 'a -> unit

Type something to start searching.