AutoOpenResizeArrayExtensions Module
Extension methods for ResizeArray<'T>. This module is automatically opened when the namespace ResizeArrayT is opened.
Type extensions
| Type extension |
Description
|
||
Full Usage:
this.AsString
Parameters:
unit
Returns: string
|
A string representation of the ResizeArray including the count of entries and the first 5 entries. When used in Fable this member is inlined for reflection to work.
Extended Type:
|
||
Full Usage:
this.Clone
Parameters:
unit
Returns: ResizeArray<'T>
Modifiers: inline |
Creates a new ResizeArray that contains a shallow copy of the elements. Same as xs.Copy().
Extended Type:
|
||
Full Usage:
this.Copy
Parameters:
unit
Returns: ResizeArray<'T>
Modifiers: inline |
Creates a new ResizeArray that contains a shallow copy of the elements. Same as xs.Clone() and ResizeArray.copy. (Named like arr.Copy() in ArrayT, since arrays can't have a typed Clone() extension.)
Extended Type:
|
||
|
Use for Debugging index get/set operations. Just replace 'myList.[3]' with 'myList.DebugIdx.[3]' Throws a descriptive exception if the index is out of range, including the bad index and the ResizeArray content.
Extended Type:
|
||
Full Usage:
this.FailIfEmpty
Parameters:
string
Returns: ResizeArray<'T>
Modifiers: inline |
Returns the input ResizeArray for chaining, or raises an exception if it is empty.
Extended Type:
|
||
Full Usage:
this.FailIfLessThan
Parameters:
int
errorMessage : string
Returns: ResizeArray<'T>
Modifiers: inline |
Returns the input ResizeArray for chaining, or raises an exception if it has fewer than count elements.
Extended Type:
|
||
Full Usage:
this.First
Parameters:
unit
Returns: 'T
Modifiers: inline |
Gets or sets the first element of the ResizeArray. Same as this.[0].
Extended Type:
|
||
Full Usage:
this.FirstAndOnly
Parameters:
unit
Returns: 'T
Modifiers: inline |
Gets the only element of the ResizeArray. Fails if the ResizeArray does not have exactly one element.
Extended Type:
|
||
Full Usage:
this.Get
Parameters:
int
-
The zero-based index of the element to get.
Returns: 'T
The element at the specified index.
Modifiers: inline |
Gets the element at the specified index. Same as this.[index] or this.Idx(index). Use this.GetNeg(index) if you want to use negative indices too.
Extended Type:
|
||
Full Usage:
this.GetLooped
Parameters:
int
-
The index to normalize into the bounds of the ResizeArray.
Returns: 'T
The element at the normalized index.
Modifiers: inline |
Gets the element at the specified index, treating the ResizeArray as circular in both directions.
Extended Type:
|
||
Full Usage:
this.GetNeg
Parameters:
int
-
The index of the element to get.
Returns: 'T
The element at the specified index.
Modifiers: inline |
Gets the element at the specified index. A negative index counts backward from the end; -1 is the last element.
Extended Type:
|
||
Full Usage:
this.GetReverseIndex
Parameters:
'a
offset : int
-
The offset from the end.
Returns: int
The corresponding index from the start. It may be outside the ResizeArray.
Type parameters: 'a |
Get the index for the element offset elements away from the end of the collection. This member exists to support F# indexing from back: ^0 is last item, ^1 is second last. (Indexing from the end with the '^' prefix needs LangVersion preview.) Just like for F# arrays, the offset is not validated here, so that slicing with an offset beyond the start, e.g. xs.[..^5] on three items, returns an empty ResizeArray instead of failing. Indexing with such an offset, e.g. xs.[^5], still fails in the ResizeArray indexer.
Extended Type:
|
||
Full Usage:
this.GetSlice
Parameters:
int option
endIdx : int option
Returns: ResizeArray<'T>
|
This member enables the F# slicing notation operator, for example xs.[1..3]. The resulting ResizeArray includes the end index. Just like for F# arrays, out-of-bounds indices are ignored when getting a slice, but not when setting one. The start index is inclusive and the end index is also inclusive. (With LangVersion preview, F# also supports slicing from the end with the '^' prefix, e.g. xs.[1..^1] skips the first and last item.)
Extended Type:
|
||
Full Usage:
this.HasItems
Parameters:
unit
Returns: bool
Modifiers: inline |
Returns true if the ResizeArray has one or more elements; otherwise, false. Same as xs.IsNotEmpty. Unlike ResizeArray.hasItems, this property does not test for an exact count.
Extended Type:
|
||
Full Usage:
this.Idx
Parameters:
int
Returns: 'T
Modifiers: inline |
Gets an item at index, same as this.[index] or this.Get(index) Throws a descriptive exception if the index is out of range. (Use this.GetNeg(i) member if you want to use negative indices too)
Extended Type:
|
||
Full Usage:
this.InsertAtStart
Parameters:
'T
Modifiers: inline |
Insert an item at the beginning of the list = index 0, (moving all other items up by one index)
Extended Type:
|
||
Full Usage:
this.IsEmpty
Parameters:
unit
Returns: bool
Modifiers: inline |
Returns true if the ResizeArray is empty; otherwise, false.
Extended Type:
|
||
Full Usage:
this.IsEqualTo
Parameters:
ResizeArray<'T>
Returns: bool
|
Shallow Structural equality comparison. Compares each element in both lists for equality. However nested ResizeArrays inside a ResizeArray are only compared for referential equality in .NET. When used in Fable (JavaScript) the nested ResizeArrays are compared for structural equality as per the Fable implementation of Javascript Arrays. (Like the default behavior of Collections.Generic.List) Does not raise ArgumentNullException if either or both lists are null.
Extended Type:
|
||
Full Usage:
this.IsNotEmpty
Parameters:
unit
Returns: bool
Modifiers: inline |
Returns true if the ResizeArray has one or more elements; otherwise, false. Same as xs.HasItems.
Extended Type:
|
||
Full Usage:
this.IsSingleton
Parameters:
unit
Returns: bool
Modifiers: inline |
Returns true if the ResizeArray has exactly one element; otherwise, false.
Extended Type:
|
||
Full Usage:
this.Last
Parameters:
unit
Returns: 'T
Modifiers: inline |
Gets or sets the last element of the ResizeArray. Same as this.[this.Count - 1].
Extended Type:
|
||
Full Usage:
this.LastIndex
Parameters:
unit
Returns: int
Modifiers: inline |
Gets the index of the last item in the ResizeArray. Equal to this.Count - 1 Returns -1 for empty ResizeArray.
Extended Type:
|
||
Full Usage:
this.Pop
Parameters:
unit
Returns: 'T
The removed element.
Modifiers: inline |
Removes and returns the last element of the ResizeArray.
In Fable, this emits
Extended Type:
|
||
Full Usage:
this.Pop
Parameters:
int
-
The zero-based index of the element to remove.
Returns: 'T
The removed element.
Modifiers: inline |
Removes and returns the element at the specified index.
Extended Type:
|
||
Full Usage:
this.PopOff
Parameters:
unit
Modifiers: inline |
Removes the last element of the ResizeArray without returning it.
In Fable, this emits
Extended Type:
|
||
Full Usage:
this.Second
Parameters:
unit
Returns: 'T
Modifiers: inline |
Gets or sets the second element of the ResizeArray. Same as this.[1].
Extended Type:
|
||
Full Usage:
this.SecondLast
Parameters:
unit
Returns: 'T
Modifiers: inline |
Gets or sets the second-last element of the ResizeArray. Same as this.[this.Count - 2].
Extended Type:
|
||
Full Usage:
this.Set
Parameters:
int
-
The zero-based index of the element to set.
value : 'T
-
The new value.
Modifiers: inline |
Sets the element at the specified index. Use this.SetNeg(index, value) if you want to use negative indices too.
Extended Type:
|
||
Full Usage:
this.SetLooped
Parameters:
int
-
The index to normalize into the bounds of the ResizeArray.
value : 'T
-
The new value.
Modifiers: inline |
Sets the element at the specified index, treating the ResizeArray as circular in both directions.
Extended Type:
|
||
Full Usage:
this.SetNeg
Parameters:
int
-
The index of the element to set.
value : 'T
-
The new value.
Modifiers: inline |
Sets the element at the specified index. A negative index counts backward from the end; -1 is the last element.
Extended Type:
|
||
Full Usage:
this.SetSlice
Parameters:
int option
endIdx : int option
newValues : IList<'T>
|
This member enables F# slicing notation operator e.g.: xs.[1..3] <- ys. The end index is included. Just like for F# arrays, out-of-bounds indices raise an exception when setting a slice, but not when getting one. If the list of new values is longer than the slice, the extra values are ignored (just like for F# arrays). (With LangVersion preview, F# also supports slicing from the end with the '^' prefix, e.g. xs.[1..^1] <- ys.)
Extended Type:
|
||
Full Usage:
this.SliceIdx
Parameters:
int
-
The inclusive start index of the slice.
endIdx : int
-
The inclusive end index of the slice.
Returns: ResizeArray<'T>
A new ResizeArray containing the requested range.
|
Returns a new ResizeArray containing the elements between the specified inclusive start and end indices. This member rejects negative and out-of-bounds indices, while the F# slicing notation xs.[1..3] does not. To allow negative indices use SliceNeg, to normalize any index with modulo use SliceLooped. Do not confuse this member with the xs.Slice(start, length) method that is built into .NET.
Extended Type:
|
||
Full Usage:
this.SliceLooped
Parameters:
int
-
The inclusive start index to normalize.
endIdx : int
-
The inclusive end index to normalize.
Returns: ResizeArray<'T>
A new ResizeArray containing the requested range.
|
Returns a new ResizeArray containing the elements between the specified start and end indices after normalizing both indices with modulo. Both indices are inclusive, and negative and out-of-range indices are allowed. If the normalized start index is greater than the normalized end index, an empty ResizeArray is returned. For an empty input ResizeArray, an empty ResizeArray is returned.
Extended Type:
|
||
Full Usage:
this.SliceNeg
Parameters:
int
-
The start index (inclusive, can be negative).
endIdx : int
-
The end index (inclusive, can be negative).
Returns: ResizeArray<'T>
A new ResizeArray containing the sliced elements.
|
Slice the ResizeArray given start and end index. Allows for negative indices too. ( -1 is last item, like Python) The resulting ResizeArray includes the end index. If the end index is one less than the start index an empty ResizeArray is returned. If you don't want an exception to be raised for index overflow or overlap use ResizeArray.trim. To reject negative indices use SliceIdx, to normalize any index with modulo use SliceLooped. Do not confuse this member with the xs.Slice(start, length) method that is built into .NET. (With LangVersion preview, F# also supports slicing from the end with the '^' prefix, e.g. xs.[1..^1] skips the first and last item.)
Extended Type:
|
||
Full Usage:
this.Third
Parameters:
unit
Returns: 'T
Modifiers: inline |
Gets or sets the third element of the ResizeArray. Same as this.[2].
Extended Type:
|
||
Full Usage:
this.ThirdLast
Parameters:
unit
Returns: 'T
Modifiers: inline |
Gets or sets the third-last element of the ResizeArray. Same as this.[this.Count - 3].
Extended Type:
|
||
Full Usage:
this.ToString
Parameters:
int
Returns: string
|
A string representation of the ResizeArray including the count of entries and the specified amount of entries. When used in Fable this member is inlined for reflection to work.
Extended Type:
|
ResizeArray