Logo ResizeArray

DebugIndexer<'T> Type

A simple wrapper for a ResizeArray. Its sole purpose is to provide a better exception message when an index is out of range.

Constructors

Constructor Description

DebugIndexer(arr)

Full Usage: DebugIndexer(arr)

Parameters:
    arr : ResizeArray<'T>

Returns: DebugIndexer<'T>
arr : ResizeArray<'T>
Returns: DebugIndexer<'T>

Instance members

Instance member Description

this.Array

Full Usage: this.Array

Returns: ResizeArray<'T>

Gets the wrapped ResizeArray.

Returns: ResizeArray<'T>

this.Count

Full Usage: this.Count

Returns: int

Gets the number of elements in the wrapped ResizeArray.

Returns: int

this[i]

Full Usage: this[i]

Returns: int

Gets or sets the element at the given index and throws a descriptive exception when the index is out of range.

Returns: int

Type something to start searching.