Logo ResizeArray

ResizeArrayT Namespace

Modules Description

Array

This module has only one conversion function. Array.asResizeArray

AutoOpenComputationalExpression

This module is automatically opened when the namespace ResizeArrayT is opened. It provides a computational expression builder for ResizeArray<'T>. resizeArray { ... } This builder allows you to create a ResizeArray just like you would create a IEnumerable with seq expressions seq { ... }.

AutoOpenResizeArrayExtensions

Extension methods for ResizeArray<'T>. This module is automatically opened when the namespace ResizeArrayT is opened.

Operators

Open this module to get access to the operators +++ and ++ to combines the contents of two Sequences or ICollection<'T> into a new ResizeArray

ResizeArray

The main module for functions on ResizeArray. A ResizeArray is a System.Collections.Generic.List<'T>. This module has all functions from the FSharp.Core.Array module implemented for ResizeArray. And more.

Type something to start searching.