ComputationalExpressionBuilderResizeArray<'T> Type
Builds ResizeArray values using F# computation-expression syntax.
Constructors
| Constructor |
Description
|
Full Usage:
ComputationalExpressionBuilderResizeArray()
Returns: ComputationalExpressionBuilderResizeArray<'T>
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Combine
Parameters:
ResizeArray<'T> -> unit
-
The first body.
g : ResizeArray<'T> -> 'a
-
The second body.
Returns: ResizeArray<'T> -> 'a
Modifiers: inline |
Combines two consecutive computation-expression bodies.
|
Full Usage:
this.Delay
Parameters:
unit -> ResizeArray<'T> -> 'a
-
The function that creates the delayed body.
Returns: ResizeArray<'T> -> 'a
Modifiers: inline |
Delays creation of a computation-expression body until it is executed.
|
Full Usage:
this.For
Parameters:
'U seq
-
The sequence to iterate.
body : 'U -> ResizeArray<'T> -> unit
-
The body to execute for each value.
Returns: ResizeArray<'T> -> unit
Modifiers: inline |
Iterates a sequence and executes the body for each value.
This always allocates a sequence and an enumerator, even for
|
Full Usage:
this.Run
Parameters:
ResizeArray<'T> -> unit
-
The body to execute.
Returns: ResizeArray<'T>
Modifiers: inline |
Executes the computation-expression body and returns the resulting ResizeArray.
|
Full Usage:
this.TryFinally
Parameters:
ResizeArray<'T> -> unit
-
The body to execute.
compensation : ResizeArray<'T> -> unit
-
The compensation to execute afterwards.
Returns: ResizeArray<'T> -> unit
Modifiers: inline |
Executes the compensation after the body completes or raises an exception.
|
Full Usage:
this.TryWith
Parameters:
ResizeArray<'T> -> unit
-
The body to execute.
handler : exn -> ResizeArray<'T> -> unit
-
The exception handler.
Returns: ResizeArray<'T> -> unit
Modifiers: inline |
Executes the body and invokes the handler if the body raises an exception.
|
Full Usage:
this.Using
Parameters:
'a
-
The resource to dispose.
body : 'a -> ResizeArray<'T> -> unit
-
The body to execute with the resource.
Returns: ResizeArray<'T> -> unit
Modifiers: inline |
Executes the body and disposes the supplied resource afterwards.
|
Full Usage:
this.While
Parameters:
unit -> bool
-
The function that controls iteration.
body : ResizeArray<'T> -> unit
-
The body to execute.
Returns: ResizeArray<'T> -> unit
Modifiers: inline |
Repeatedly executes the body while the predicate returns true.
|
Full Usage:
this.Yield
Parameters:
'T
-
The value to add.
Returns: ResizeArray<'T> -> unit
Modifiers: inline |
Adds one value to the ResizeArray produced by the computation expression.
|
Full Usage:
this.YieldFrom
Parameters:
'a
-
The sequence of values to add.
Returns: ResizeArray<'T0> -> unit
Modifiers: inline |
Adds all values from a sequence to the ResizeArray produced by the computation expression.
|
Full Usage:
this.Zero
Returns: 'a -> unit
Modifiers: inline |
Called for empty else branches of if...then expressions in computation expressions.
|
ResizeArray