Operators Module
Open this module to get access to the operators +++ and ++ to combine the contents of two sequences or ICollection<'T> values into a new ResizeArray.
Functions and values
| Function or value |
Description
|
Full Usage:
a ++ b
Parameters:
ICollection<'T>
b : ICollection<'T>
Returns: ResizeArray<'T>
Modifiers: inline Type parameters: 'T |
Operator ++ to shallow copy the contents of two ICollection<'T> into a new ResizeArray. The capacity of the new ResizeArray is the sum of the count of the two ICollection<'T>. This version is more optimized than the +++ operator for sequences because it can preallocate the required space.
|
Full Usage:
a +++ b
Parameters:
'T seq
b : 'T seq
Returns: ResizeArray<'T>
Modifiers: inline Type parameters: 'T |
Operator +++ shallow-copies the contents of two sequences (IEnumerable<'T>) into a new ResizeArray. On ICollection<'T> you can also use the more optimized ++ operator.
|
ResizeArray