DebugIndexer<'T> Type
A simple wrapper for a ResizeArray. Its sole purpose is to provide a better exception message when an index is out of range.
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Array
Returns: ResizeArray<'T>
|
Gets the wrapped ResizeArray.
|
Full Usage:
this.Count
Returns: int
|
Gets the number of elements in the wrapped ResizeArray.
|
Full Usage:
this[i]
Returns: int
|
Gets or sets the element at the given index and throws a descriptive exception when the index is out of range.
|
ResizeArray